Handshakes
==========

.. automodule:: siotls.contents.handshakes
   :members:

The following modules define the concretes classes for :class:`Handshake`:

.. toctree::
   :maxdepth: 1

   certificate
   certificate_request
   certificate_verify
   client_hello
   encrypted_extensions
   end_of_early_data
   finished
   key_update
   new_session_ticket
   server_hello

.. toctree::
   :hidden:

   extensions/index
